@@ -1,4 +1,4 @@
-/*	$OpenBSD: database.c,v 1.19 2006/03/13 09:36:06 claudio Exp $ */
+/*	$OpenBSD: database.c,v 1.22 2008/02/11 12:37:37 norby Exp $ */
 
 /*
  * Copyright (c) 2005 Claudio Jeker <claudio@openbsd.org>
@@ -45,6 +45,7 @@ send_db_description(struct nbr *nbr)
 	struct lsa_entry	*le, *nle;
 	struct buf		*buf;
 	int			 ret = 0;
+	u_int8_t		 bits = 0;
 
 	if ((buf = buf_open(nbr->iface->mtu - sizeof(struct ip))) == NULL)
 		fatal("send_db_description");
@@ -69,23 +70,24 @@ send_db_description(struct nbr *nbr)
 		ret = -1;
 		goto done;
 	case NBR_STA_XSTRT:
-		nbr->options |= OSPF_DBD_MS | OSPF_DBD_M | OSPF_DBD_I;
+		bits |= OSPF_DBD_MS | OSPF_DBD_M | OSPF_DBD_I;
+		nbr->dd_more = 1;
 		break;
 	case NBR_STA_XCHNG:
-		if (nbr->master) {
-			/* master */
-			nbr->options |= OSPF_DBD_MS;
+		if (nbr->dd_master)
+			bits |= OSPF_DBD_MS;
+		else
+			bits &= ~OSPF_DBD_MS;
+
+		if (TAILQ_EMPTY(&nbr->db_sum_list)) {
+			bits &= ~OSPF_DBD_M;
+			nbr->dd_more = 0;
 		} else {
-			/* slave */
-			nbr->options &= ~OSPF_DBD_MS;
+			bits |= OSPF_DBD_M;
+			nbr->dd_more = 1;
 		}
 
-		if (TAILQ_EMPTY(&nbr->db_sum_list))
-			nbr->options &= ~OSPF_DBD_M;
-		else
-			nbr->options |= OSPF_DBD_M;
-
-		nbr->options &= ~OSPF_DBD_I;
+		bits &= ~OSPF_DBD_I;
 
 		/* build LSA list, keep space for a possible md5 sum */
 		for (le = TAILQ_FIRST(&nbr->db_sum_list); le != NULL &&
@@ -98,16 +100,14 @@ send_db_description(struct nbr *nbr)
 		break;
 	case NBR_STA_LOAD:
 	case NBR_STA_FULL:
-		if (nbr->master) {
-			/* master */
-			nbr->options |= OSPF_DBD_MS;
-		} else {
-			/* slave */
-			nbr->options &= ~OSPF_DBD_MS;
-		}
-		nbr->options &= ~OSPF_DBD_M;
-		nbr->options &= ~OSPF_DBD_I;
+		if (nbr->dd_master)
+			bits |= OSPF_DBD_MS;
+		else
+			bits &= ~OSPF_DBD_MS;
+		bits &= ~OSPF_DBD_M;
+		bits &= ~OSPF_DBD_I;
 
+		nbr->dd_more = 0;
 		break;
 	default:
 		fatalx("send_db_description: unknown neighbor state");
@@ -138,8 +138,8 @@ send_db_description(struct nbr *nbr)
 		fatalx("send_db_description: unknown interface type");
 	}
 
-	dd_hdr.opts = oeconf->options;
-	dd_hdr.bits = nbr->options;
+	dd_hdr.opts = area_ospf_options(nbr->iface->area);
+	dd_hdr.bits = bits;
 	dd_hdr.dd_seq_num = htonl(nbr->dd_seq_num);
 
 	memcpy(buf_seek(buf, sizeof(struct ospf_hdr), sizeof(dd_hdr)),
@@ -167,7 +167,7 @@ recv_db_description(struct nbr *nbr, char *buf, u_int16_t len)
 	int			 dupe = 0;
 
 	if (len < sizeof(dd_hdr)) {
-		log_warnx("recv_dd_description: "
+		log_warnx("recv_db_description: "
 		    "bad packet size, neighbor ID %s", inet_ntoa(nbr->id));
 		return;
 	}
@@ -177,7 +177,7 @@ recv_db_description(struct nbr *nbr, char *buf, u_int16_t len)
 
 	/* db description packet sanity checks */
 	if (ntohs(dd_hdr.iface_mtu) > nbr->iface->mtu) {
-		log_warnx("recv_dd_description: invalid MTU %d sent by "
+		log_warnx("recv_db_description: invalid MTU %d sent by "
 		    "neighbor ID %s, expected %d", ntohs(dd_hdr.iface_mtu),
 		    inet_ntoa(nbr->id), nbr->iface->mtu);
 		return;
@@ -185,7 +185,8 @@ recv_db_description(struct nbr *nbr, char *buf, u_int16_t len)
 
 	if (nbr->last_rx_options == dd_hdr.opts &&
 	    nbr->last_rx_bits == dd_hdr.bits &&
-	    ntohl(dd_hdr.dd_seq_num) == nbr->dd_seq_num - nbr->master ? 1 : 0) {
+	    ntohl(dd_hdr.dd_seq_num) == nbr->dd_seq_num - nbr->dd_master ?
+	    1 : 0) {
 			log_debug("recv_db_description: dupe");
 			dupe = 1;
 	}
@@ -217,7 +218,7 @@ recv_db_description(struct nbr *nbr, char *buf, u_int16_t len)
 			if ((ntohl(nbr->id.s_addr)) >
 			    ntohl(ospfe_router_id())) {
 				/* slave */
-				nbr->master = 0;
+				nbr->dd_master = 0;
 				nbr->dd_seq_num = ntohl(dd_hdr.dd_seq_num);
 
 				/* event negotiation done */
@@ -255,7 +256,7 @@ recv_db_description(struct nbr *nbr, char *buf, u_int16_t len)
 	case NBR_STA_LOAD:
 	case NBR_STA_FULL:
 		if (dd_hdr.bits & OSPF_DBD_I ||
-		    !(dd_hdr.bits & OSPF_DBD_MS) == !nbr->master) {
+		    !(dd_hdr.bits & OSPF_DBD_MS) == !nbr->dd_master) {
 			log_warnx("recv_db_description: seq num mismatch, "
 			    "bad flags");
 			nbr_fsm(nbr, NBR_EVT_SEQ_NUM_MIS);
@@ -270,7 +271,7 @@ recv_db_description(struct nbr *nbr, char *buf, u_int16_t len)
 		}
 
 		if (dupe) {
-			if (!nbr->master)
+			if (!nbr->dd_master)
 				/* retransmit */
 				start_db_tx_timer(nbr);
 			return;
@@ -285,7 +286,7 @@ recv_db_description(struct nbr *nbr, char *buf, u_int16_t len)
 		}
 
 		/* sanity check dd seq number */
-		if (nbr->master) {
+		if (nbr->dd_master) {
 			/* master */
 			if (ntohl(dd_hdr.dd_seq_num) != nbr->dd_seq_num) {
 				log_warnx("recv_db_description: invalid "
@@ -320,7 +321,7 @@ recv_db_description(struct nbr *nbr, char *buf, u_int16_t len)
 
 		if (!(dd_hdr.bits & OSPF_DBD_M) &&
 		    TAILQ_EMPTY(&nbr->db_sum_list))
-			if (!nbr->master || !(nbr->options & OSPF_DBD_M))
+			if (!nbr->dd_master || !nbr->dd_more)
 				nbr_fsm(nbr, NBR_EVT_XCHNG_DONE);
 		break;
 	default:
@@ -390,7 +391,7 @@ db_tx_timer(int fd, short event, void *arg)
 	}
 
 	/* reschedule db_tx_timer but only in master mode */
-	if (nbr->master) {
+	if (nbr->dd_master) {
 		timerclear(&tv);
 		tv.tv_sec = nbr->iface->rxmt_interval;
 		if (evtimer_add(&nbr->db_tx_timer, &tv) == -1)
