@@ -1,4 +1,4 @@
-/*	$OpenBSD: ospfd.c,v 1.56 2007/10/25 12:06:30 claudio Exp $ */
+/*	$OpenBSD: ospfd.c,v 1.57 2008/05/12 19:15:02 pyr Exp $ */
 
 /*
  * Copyright (c) 2005 Claudio Jeker <claudio@openbsd.org>
@@ -170,6 +170,11 @@ main(int argc, char *argv[])
 		}
 	}
 
+	argc -= optind;
+	argv += optind;
+	if (argc > 0)
+		usage();
+
 	mib[0] = CTL_NET;
 	mib[1] = PF_INET;
 	mib[2] = IPPROTO_IP;
