@@ -1,4 +1,4 @@
-/*	$OpenBSD: printconf.c,v 1.5 2006/05/31 03:59:51 claudio Exp $ */
+/*	$OpenBSD: printconf.c,v 1.11 2007/09/30 13:28:09 claudio Exp $ */
 
 /*
  * Copyright (c) 2004, 2005 Esben Norby <norby@openbsd.org>
@@ -31,6 +31,7 @@
 void	print_mainconf(struct ospfd_conf *);
 const char *print_no(u_int16_t);
 void	print_redistribute(struct ospfd_conf *);
+void	print_rtlabel(struct ospfd_conf *);
 void	print_iface(struct iface *);
 
 void
@@ -38,17 +39,21 @@ print_mainconf(struct ospfd_conf *conf)
 {
 	printf("router-id %s\n", inet_ntoa(conf->rtr_id));
 
-	if (conf->flags |= OSPFD_FLAG_NO_FIB_UPDATE)
-		printf("fib-update yes\n");
-	else
+	if (conf->flags & OSPFD_FLAG_NO_FIB_UPDATE)
 		printf("fib-update no\n");
+	else
+		printf("fib-update yes\n");
 
 	if (conf->rfc1583compat)
 		printf("rfc1583compat yes\n");
 	else
 		printf("rfc1583compat no\n");
 
+	if (conf->flags & OSPFD_FLAG_STUB_ROUTER)
+		printf("stub router yes\n");
+
 	print_redistribute(conf);
+	print_rtlabel(conf);
 
 	printf("spf-delay %u\n", conf->spf_delay);
 	printf("spf-holdtime %u\n", conf->spf_hold_time);
@@ -84,7 +89,7 @@ print_redistribute(struct ospfd_conf *conf)
 			    print_no(r->type), rtlabel_id2name(r->label));
 			break;
 		case REDIST_ADDR:
-			printf("%ssredistribute %s/%d\n",
+			printf("%sredistribute %s/%d\n",
 			    print_no(r->type), inet_ntoa(r->addr),
 			    mask2prefixlen(r->mask.s_addr));
 			break;
@@ -92,18 +97,31 @@ print_redistribute(struct ospfd_conf *conf)
 	}
 }
 
+void
+print_rtlabel(struct ospfd_conf *conf)
+{
+	struct n2id_label	*label;
+
+	TAILQ_FOREACH(label, &rt_labels, entry)
+		if (label->ext_tag)
+			printf("rtlabel \"%s\" external-tag %u\n",
+			    label->name, label->ext_tag);
+}
+
 void
 print_iface(struct iface *iface)
 {
 	struct auth_md	*md;
 
-	printf("\tinterface %s {\n", iface->name);
+	printf("\tinterface %s:%s {\n", iface->name, inet_ntoa(iface->addr));
 
 	printf("\t\thello-interval %d\n", iface->hello_interval);
 	printf("\t\tmetric %d\n", iface->metric);
 
 	if (iface->passive)
 		printf("\t\tpassive\n");
+	if (*iface->demote_group)
+		printf("\t\tdemote %s\n", iface->demote_group);
 
 	printf("\t\tretransmit-interval %d\n", iface->rxmt_interval);
 	printf("\t\trouter-dead-time %d\n", iface->dead_interval);
@@ -142,6 +160,9 @@ print_config(struct ospfd_conf *conf)
 
 	LIST_FOREACH(area, &conf->area_list, entry) {
 		printf("area %s {\n", inet_ntoa(area->id));
+		if (*area->demote_group)
+			printf("\tdemote %s %d\n", area->demote_group,
+			area->demote_level);
 		LIST_FOREACH(iface, &area->iface_list, entry) {
 			print_iface(iface);
 		}
